#ifndef PGGUI_H
#define PGGUI_H

//#include <QtGui/QWidget>
#include <QtGui>

#include<QProcess>
#include<QDebug>
 #ifdef Q_WS_MAEMO_5
    #include <QMaemo5InformationBox>
#endif
#include "passworddialog.h"


class QLineEdit;
class QTextEdit;
class QLabel;
class QProcess;

class pggui : public QWidget
{
    Q_OBJECT

public:
    pggui(QWidget *parent = 0);
    QLineEdit *passwordLine;

    ~pggui();

public slots:
    void pgguiAbout();
    void slotStringReceived();
    void slotErrorStringReceived();
    void gpgDecryption();
    void gpgEncryption();
    void gpgDecode();
    void gpgImportKey();

private:
    QTextEdit *gpgText;

    passwordDialog *dialog;

    QString *strLine;

   // QString *password;

    QMainWindow *KeyManagmentWindow;
    QMainWindow *gpgEnterKeyWindow;

    QPushButton *pgguiAboutButton;
    QPushButton *gpgEncryptButton;
    QPushButton *gpgDecryptButton;
    QPushButton *gpgKeyManagmentButton;
    QPushButton *gpgCreateKeysButton;
    QPushButton *gpgImportKeysButton;

    QProcess *gpg;
};

#endif // PGGUI_H
